==> RsCMX_Signaling-4.0.120.tar.gz: RsCMX_Signaling-4.0.120/RsCMX_Signaling/Implementations/Configure/Signaling/Nradio/Cell/RfSettings/Downlink/Ibwp/Lobw.py <==
from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Types import DataType
from .........Internal.ArgSingleList import ArgSingleList
from .........Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LobwCls:
	"""Lobw commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lobw", core, parent)

	def set(self, cell_name: str, lobw: int) -> None:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:RFSettings:DL:IBWP:LOBW \n
		Snippet: driver.configure.signaling.nradio.cell.rfSettings.downlink.ibwp.lobw.set(cell_name = '1', lobw = 1) \n
		Defines the resource indication value (RIV) signaled as 'locationAndBandwidth', for the downlink. \n
			:param cell_name: No help available
			:param lobw: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('lobw', lobw, DataType.Integer))
		self._core.io.write(f'CONFigure:SIGNaling:NRADio:CELL:RFSettings:DL:IBWP:LOBW {param}'.rstrip())

	def get(self, cell_name: str) -> int:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:RFSettings:DL:IBWP:LOBW \n
		Snippet: value: int = driver.configure.signaling.nradio.cell.rfSettings.downlink.ibwp.lobw.get(cell_name = '1') \n
		Defines the resource indication value (RIV) signaled as 'locationAndBandwidth', for the downlink. \n
			:param cell_name: No help available
			:return: lobw: No help available"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:NRADio:CELL:RFSettings:DL:IBWP:LOBW? {param}')
		return Conversions.str_to_int(response)

==> RsCMX_Signaling-7.70.0.tar.gz: RsCMX_Signaling-7.70.0/RsCMX_Signaling/Implementations/Configure/Signaling/Nradio/Cell/RfSettings/Downlink/Ibwp/Lobw.py <==
from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Types import DataType
from .........Internal.ArgSingleList import ArgSingleList
from .........Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LobwCls:
	"""Lobw commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lobw", core, parent)

	def set(self, cell_name: str, lobw: int) -> None:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:RFSettings:DL:IBWP:LOBW \n
		Snippet: driver.configure.signaling.nradio.cell.rfSettings.downlink.ibwp.lobw.set(cell_name = 'abc', lobw = 1) \n
		No command help available \n
			:param cell_name: No help available
			:param lobw: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('lobw', lobw, DataType.Integer))
		self._core.io.write(f'CONFigure:SIGNaling:NRADio:CELL:RFSettings:DL:IBWP:LOBW {param}'.rstrip())

	def get(self, cell_name: str) -> int:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:RFSettings:DL:IBWP:LOBW \n
		Snippet: value: int = driver.configure.signaling.nradio.cell.rfSettings.downlink.ibwp.lobw.get(cell_name = 'abc') \n
		No command help available \n
			:param cell_name: No help available
			:return: lobw: No help available"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:NRADio:CELL:RFSettings:DL:IBWP:LOBW? {param}')
		return Conversions.str_to_int(response)
